@@ -255,9 +255,10 @@ class ResponseListTestCase(unittest.TestCase):
             SuccessfulResponseMock(None, 1)
         ])
 
+        self.assertEqual(rs.stats_packets_sent, rs.stats_packets_returned, 'unable to correctly count sent and returned packets when all responses successful')
         self.assertEqual(
-            rs.packet_loss, 
-            0.0, 
+            rs.stats_packets_lost, 
+            0, 
             "Unable to calculate packet loss correctly when all responses successful"
         )
 
@@ -268,9 +269,9 @@ class ResponseListTestCase(unittest.TestCase):
             FailingResponseMock(None, 1),
             FailingResponseMock(None, 1)
         ])
-
+        self.assertEqual(rs.stats_packets_returned, 0, 'unable to correctly count sent and returned packets when all responses failed')
         self.assertEqual(
-            rs.packet_loss, 
+            rs.stats_lost_ratio, 
             1.0, 
             "Unable to calculate packet loss correctly when all responses failed"
         )
@@ -282,9 +283,10 @@ class ResponseListTestCase(unittest.TestCase):
             FailingResponseMock(None, 1),
             FailingResponseMock(None, 1)
         ])
-
+        self.assertEqual(rs.stats_packets_sent, 4, 'unable to correctly count sent packets when some of the responses failed')
+        self.assertEqual(rs.stats_packets_returned, 2, 'unable to correctly count returned packets when some of the responses failed')
         self.assertEqual(
-            rs.packet_loss, 
+            rs.stats_lost_ratio, 
             0.5, 
             "Unable to calculate packet loss correctly when some of the responses failed"
         )
@@ -296,7 +298,8 @@ class ResponseListTestCase(unittest.TestCase):
             FailingResponseMock(None, 1),
             SuccessfulResponseMock(None, 1),
         ])
-
+        self.assertEqual(rs.stats_packets_sent, 4, 'unable to correctly count sent packets when when failing responses are mixed with successful responses')
+        self.assertEqual(rs.stats_packets_returned, 2, 'unable to correctly count returned packets when failing responses are mixed with successful responses')
         self.assertEqual(
             rs.packet_loss,
             0.5,
